# Test Mapping Output
Mappings generated by test_rewrite_rules.py

| Input URL | Accept | Output URL |
| ----- | ----- | ----- |
| https://w3id.org/linkml/ | text/html | https://linkml.github.io/linkml-model/docs/ |
| https://w3id.org/linkml/Boolean | text/html | https://linkml.github.io/linkml-model/docs/Boolean |
| https://w3id.org/linkml/Element | text/html | https://linkml.github.io/linkml-model/docs/Element |
| https://w3id.org/linkml/context.jsonld | text/html | https://linkml.github.io/linkml-model/linkml_model/jsonld/context.jsonld |
| https://w3id.org/linkml/meaning | text/html | https://linkml.github.io/linkml-model/docs/meaning |
| https://w3id.org/linkml/meta | application/json | https://linkml.github.io/linkml-model/linkml_model/json/meta.json |
| https://w3id.org/linkml/meta | application/ld+json | https://linkml.github.io/linkml-model/linkml_model/jsonld/meta.context.jsonld |
| https://w3id.org/linkml/meta | text/yaml | https://linkml.github.io/linkml-model/linkml_model/model/schema/meta.yaml |
| https://w3id.org/linkml/meta | text/turtle | https://linkml.github.io/linkml-model/linkml_model/rdf/meta.ttl |
| https://w3id.org/linkml/meta | text/shex | https://linkml.github.io/linkml-model/linkml_model/shex/meta.shex |
| https://w3id.org/linkml/meta | text/foo | https://linkml.github.io/linkml-model/meta |
| https://w3id.org/linkml/meta.context.jsonld | text/html | https://linkml.github.io/linkml-model/linkml_model/jsonld/meta.context.jsonld |
| https://w3id.org/linkml/meta.foo | text/html | https://linkml.github.io/linkml-model/meta.foo |
| https://w3id.org/linkml/meta.model.context.jsonld | text/html | https://linkml.github.io/linkml-model/linkml_model/jsonld/meta.model.context.jsonld |
| https://w3id.org/linkml/meta.owl | text/html | https://linkml.github.io/linkml-model/linkml_model/owl/meta.owl.ttl |
| https://w3id.org/linkml/types | text/html | https://linkml.github.io/linkml-model/docs/types |
| https://w3id.org/linkml/types | application/json | https://linkml.github.io/linkml-model/linkml_model/json/types.json |
| https://w3id.org/linkml/types | text/yaml | https://linkml.github.io/linkml-model/linkml_model/model/schema/types.yaml |
| https://w3id.org/linkml/types | text/turtle | https://linkml.github.io/linkml-model/linkml_model/rdf/types.ttl |
| https://w3id.org/linkml/types | text/shex | https://linkml.github.io/linkml-model/linkml_model/shex/types.shex |
| https://w3id.org/linkml/types.context.jsonld | text/html | https://linkml.github.io/linkml-model/linkml_model/jsonld/types.context.jsonld |
| https://w3id.org/linkml/types.owl | text/html | https://linkml.github.io/linkml-model/linkml_model/owl/types.owl.ttl |
| https://w3id.org/linkml/types/ | text/html | https://linkml.github.io/linkml-model/types/ |
| https://w3id.org/linkml/types/abc | text/html | https://linkml.github.io/linkml-model/docs/types/abc |
